import { Component, OnInit, AfterViewInit, Output, Input, EventEmitter, ViewChild } from '@angular/core';
import { Subject, Unsubscribable } from 'rxjs';
import { ActivatedRoute, Router } from '@angular/router';
import { NzNotificationService } from 'ng-zorro-antd/notification';
import { Http } from '@global/http/http';
import { Util } from '@global/util/util';
import { AppEnvironment } from 'src/environments/AppEnvironment';

import EditViewEngine from '@engine/view/edit-view-engine';

import { EditForm } from '@widgets/bxd/main-form/main-form';


@Component({
  selector: 'view-bxdedit-view',
  templateUrl: './bxdedit-view.page.html',
  styleUrls: ['./bxdedit-view.page.less']
})
export class BXDEditViewPage implements OnInit, AfterViewInit {

    /**
     * 构造方法
     * @param {NzNotificationService} $notice
     * @memberof IndexPage
     */
    constructor(private $util: Util, private $router: Router, private $route: ActivatedRoute, private $notice: NzNotificationService) {}


    /**
     * 子组件EditForm
     *
     * @public
     * @type {Subject}
     * @memberof BXDEditView
     */
    @ViewChild(EditForm, {static: false})
    private form: EditForm;

	/**
	 * 视图标识
	 *
	 * @type {string}
	 * @memberof AppDashboardView
	 */
	public viewtag: string = '68e8706d6a0ba1ac1fad99eac7451daf';

    /**
     * 父数据对象
     *
     * @protected
     * @type {*}
     * @memberof BXDEditView
     */
    protected srfparentdata: any = {};

    /**
     * 视图订阅对象
     *
     * @public
     * @type {Subject}
     * @memberof BXDEditView
     */
    public viewState: Subject<ViewState> = new Subject();

    /**
     * 视图值变化事件
     *
     * @public
     * @type {EventEmitter}
     * @memberof BXDEditView
     */    
    @Output() public viewdataschange = new EventEmitter();

    /**
     * 视图参数
     *
     * @public
     * @type {Subject}
     * @memberof BXDEditView
     */
    @Input() public viewdata: any;

    /**
     * 工具栏模型
     *
     * @type {*}
     * @memberof BXDEditView
     */
    public toolBarModels: any = {
        tbitem3: { name: 'tbitem3', caption: '保存', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Save', target: '' } },

        tbitem4: { name: 'tbitem4', caption: '保存并新建', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'SaveAndNew', target: '' } },

        tbitem5: { name: 'tbitem5', caption: '保存并关闭', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'SaveAndExit', target: '' } },

        tbitem6: {  name: 'tbitem6', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem7: { name: 'tbitem7', caption: '删除并关闭', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'RemoveAndExit', target: 'SINGLEKEY' } },

        tbitem8: {  name: 'tbitem8', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem12: { name: 'tbitem12', caption: '新建', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'New', target: '' } },

        tbitem13: {  name: 'tbitem13', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem14: { name: 'tbitem14', caption: '拷贝', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Copy', target: 'SINGLEKEY' } },

        tbitem16: {  name: 'tbitem16', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem23: { name: 'tbitem23', caption: '第一个记录', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'FirstRecord', target: 'SINGLEKEY' } },

        tbitem24: { name: 'tbitem24', caption: '上一个记录', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'PrevRecord', target: 'SINGLEKEY' } },

        tbitem25: { name: 'tbitem25', caption: '下一个记录', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'NextRecord', target: 'SINGLEKEY' } },

        tbitem26: { name: 'tbitem26', caption: '最后一个记录', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'LastRecord', target: 'SINGLEKEY' } },

        tbitem21: {  name: 'tbitem21', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem22: { name: 'tbitem22', caption: '帮助', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Help', target: '' } },

    };


    /**
     * 视图加载完成事件
     *
     * @type {EventEmitter<any>}
     * @memberof BXDEditView
     */
    @Output() public viewloadEvent: EventEmitter<any> = new EventEmitter<any>();

    /**
     * 视图数据变化事件
     *
     * @type {EventEmitter<any>}
     * @memberof BXDEditView
     */
    @Output() public viewdataschangeEvent: EventEmitter<any> = new EventEmitter<any>();

    /**
     * 视图模型数据
     *
     * @type {*}
     * @memberof BXDEditView
     */
    public model: any = {
        srfTitle: '报销单编辑视图',
        srfCaption: '报销单',
        srfSubCaption: '',
        dataInfo: ''
    };

    /**
     * 视图引擎
     *
     * @private
     * @type {Engine}
     * @memberof BXDEditView
     */
    private engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @private
     * @memberof BXDEditView
     */
    private engineInit(): void {
        this.engine.init({
            view: this,
            form: this.form,
            isLoadDefault: true,
        });
    }

    /**
     * angular生命周期
     *
     * @memberof BXDEditView
     */
    public ngOnInit() {

    }

     /**
     * angular生命周期(在ngOnInit之后)
     *
     * @memberof BXDEditView
     */
    public ngAfterViewInit() {
        this.engineInit();
        
    }


    /**
     * toolbar 部件 click 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDEditView
     */
    public toolbar_click($event: any, $event2?: any) {
        if (Object.is($event.tag, 'tbitem3')) {
            this.toolbar_tbitem3_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem4')) {
            this.toolbar_tbitem4_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem5')) {
            this.toolbar_tbitem5_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem7')) {
            this.toolbar_tbitem7_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem9')) {
            this.toolbar_tbitem9_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem10')) {
            this.toolbar_tbitem10_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem12')) {
            this.toolbar_tbitem12_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem14')) {
            this.toolbar_tbitem14_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem15')) {
            this.toolbar_tbitem15_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem23')) {
            this.toolbar_tbitem23_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem24')) {
            this.toolbar_tbitem24_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem25')) {
            this.toolbar_tbitem25_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem26')) {
            this.toolbar_tbitem26_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem22')) {
            this.toolbar_tbitem22_click($event, '', $event2);
        }
    }


    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDEditView
     */
    public form_save($event: any, $event2?: any) {
        this.engine.onCtrlEvent('form', 'save', $event);
    }


    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDEditView
     */
    public form_remove($event: any, $event2?: any) {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }


    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDEditView
     */
    public form_load($event: any, $event2?: any) {
        this.engine.onCtrlEvent('form', 'load', $event);
    }



    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem3_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Save(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem4_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.SaveAndNew(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem5_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.SaveAndExit(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem7_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.RemoveAndExit(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem9_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.SaveAndStart(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem10_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.ViewWFStep(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem12_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.New(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem14_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Copy(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem15_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Print(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem23_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.FirstRecord(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem24_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.PrevRecord(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem25_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.NextRecord(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem26_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.LastRecord(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem22_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.form;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Help(datas, paramJO,  $event, xData);
    }


    /**
     * 保存
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public Save(args: any[], params?: any, $event?: any, xData?: any) {
        // 界面行为容器对象 _this
        const _this: any = this;
        if (xData && xData.save instanceof Function) {
            const _data = { srfparentdata: _this.srfparentdata };
            xData.save(_data).then((response: any) => {
                if (!response || response.status !== 200) {
                    return;
                }
                _this.$emit('viewdataschange', [{ ...response.data }]);
            });
        } else if (_this.save && _this.save instanceof Function) {
            _this.save();
        }
    }


    /**
     * 保存并新建
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public SaveAndNew(args: any[], params?: any, $event?: any, xData?: any) {
        const _view: any = this;
        if (!xData || !(xData.save instanceof Function)) {
            return;
        }
        const _data = { srfparentdata: _view.srfparentdata };
        xData.save(_data).then((response: any) => {
            if (!response || response.status !== 200) {
                return;
            }
            if (xData.autoLoad instanceof Function) {
                xData.autoLoad(_data);
            }
        });
    }

    /**
     * 保存并关闭
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public SaveAndExit(args: any[], params?: any, $event?: any, xData?: any) {
        // _this 指向容器对象
        // xData 数据对象
        const _this: any = this;
        if (xData && xData.save instanceof Function) {
            const _data = { srfparentdata: _this.srfparentdata };
            xData.save(_data).then((response: any) => {
                if (!response || response.status !== 200) {
                    return;
                }
                if (_this.viewdata) {
                    _this.$emit('viewdataschange', [{ ...response.data }]);
                    _this.$emit('close');
                } else if (_this.$tabPageExp) {
                    _this.$tabPageExp.onClose(_this.$route.fullPath);
                }
            });
        } else if (_this.save && _this.save instanceof Function) {
            _this.save().then((response: any) => {
                if (!response || response.status !== 200) {
                    return;
                }
                _this.$emit('closeview', [{ ...response.data }]);
            });
        }
    }

    /**
     * 删除并关闭
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public RemoveAndExit(args: any[], params?: any, $event?: any, xData?: any) {
        const _this: any = this;
        if (!xData || !(xData.remove instanceof Function)) {
            return ;
        }
        xData.remove(args).then((response: any) => {
            if (!response || response.status !== 200) {
                return ;
            }
            if (_this.viewdata) {
                _this.$emit('close');
            } else {
                _this.$tabPageExp.onClose(_this.$route.fullPath);
            }
        });
    }

    /**
     * 开始流程
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public SaveAndStart(args: any[], params?: any, $event?: any, xData?: any) {
        // _this 指向容器对象
        // xData 数据对象
        const _this: any = this;
        if (xData && xData.save instanceof Function) {
            const _data = { srfparentdata: _this.srfparentdata };
            xData.save(_data).then((response: any) => {
                if (!response || response.status !== 200) {
                    return;
                }
                const { data: _data } = response;
            });
        } else if (_this.save && _this.save instanceof Function) {
            _this.save().then((response: any) => {
                if (!response || response.status !== 200) {
                    return;
                }
                const { data: _data } = response;
            });
        }
    }

    /**
     * 当前流程步骤
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public ViewWFStep(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 新建
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public New(args: any[], params?: any, $event?: any, xData?: any) {
         const _this: any = this;
        if (_this.newdata && _this.newdata instanceof Function) {
            const data: any = {};
            if (_this.srfparentdata) {
                Object.assign(data, _this.srfparentdata);
            }
            _this.newdata([{ ...data }], params, $event, xData);
        } else {
            _this.$notice.error('错误', 'newdata 视图处理逻辑不存在，请添加!');
        }
    }

    /**
     * 拷贝
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public Copy(args: any[], params?: any, $event?: any, xData?: any) {
        if (args.length === 0) {
            return;
        }
        const _this: any = this;
        if (_this.newdata && _this.newdata instanceof Function) {
            const data: any = {};
            if (args.length > 0) {
                Object.assign(data, { srfsourcekey: args[0].srfkey })
            }
            if (_this.srfparentdata) {
                Object.assign(data, _this.srfparentdata);
            }
            _this.newdata([{ ...data }], params, $event, xData);
        } else if (xData && xData.copy instanceof Function) {
            const data2: any = {};
            if (args.length > 0) {
                Object.assign(data2, { srfsourcekey: args[0].srfkey })
            }
            if (_this.srfparentdata) {
                Object.assign(data2, _this.srfparentdata);
            }
            xData.copy(data2);
        } else {
            _this.$Notice.error({ title: '错误', desc: 'opendata 视图处理逻辑不存在，请添加!' });
        }
    }

    /**
     * 打印
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public Print(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 第一个记录
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public FirstRecord(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 上一个记录
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public PrevRecord(args: any[], params?: any, $event?: any, xData?: any) {

    }


    /**
     * 下一个记录
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public NextRecord(args: any[], params?: any, $event?: any, xData?: any) {

    }


    /**
     * 最后一个记录
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public LastRecord(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 帮助
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDEditView
     */
    public Help(args: any[], params?: any, $event?: any, xData?: any) {

    }

}
