import { Component, OnInit, AfterViewInit, Output, Input, EventEmitter, ViewChild } from '@angular/core';
import { Subject, Unsubscribable } from 'rxjs';
import { ActivatedRoute, Router } from '@angular/router';
import { NzNotificationService } from 'ng-zorro-antd/notification';
import { Http } from '@global/http/http';
import { Util } from '@global/util/util';
import { AppEnvironment } from 'src/environments/AppEnvironment';

import GridViewEngine from '@engine/view/grid-view-engine';

import { Grid } from '@widgets/bxd/main-grid/main-grid';
import { SearchForm } from '@widgets/bxd/default-searchform/default-searchform';


@Component({
  selector: 'view-bxdgrid-view',
  templateUrl: './bxdgrid-view.page.html',
  styleUrls: ['./bxdgrid-view.page.less']
})
export class BXDGridViewPage implements OnInit, AfterViewInit {

    /**
     * 构造方法
     * @param {NzNotificationService} $notice
     * @memberof IndexPage
     */
    constructor(private $util: Util, private $router: Router, private $route: ActivatedRoute, private $notice: NzNotificationService) {}


    /**
     * 子组件Grid
     *
     * @public
     * @type {Subject}
     * @memberof BXDGridView
     */
    @ViewChild(Grid, {static: false})
    private grid: Grid;
    /**
     * 子组件SearchForm
     *
     * @public
     * @type {Subject}
     * @memberof BXDGridView
     */
    @ViewChild(SearchForm, {static: false})
    private searchform: SearchForm;

	/**
	 * 视图标识
	 *
	 * @type {string}
	 * @memberof AppDashboardView
	 */
	public viewtag: string = '7ec2083177032569af2eeebadfdf64e4';

    /**
     * 父数据对象
     *
     * @protected
     * @type {*}
     * @memberof BXDGridView
     */
    protected srfparentdata: any = {};

    /**
     * 视图订阅对象
     *
     * @public
     * @type {Subject}
     * @memberof BXDGridView
     */
    public viewState: Subject<ViewState> = new Subject();

    /**
     * 视图值变化事件
     *
     * @public
     * @type {EventEmitter}
     * @memberof BXDGridView
     */    
    @Output() public viewdataschange = new EventEmitter();

    /**
     * 视图参数
     *
     * @public
     * @type {Subject}
     * @memberof BXDGridView
     */
    @Input() public viewdata: any;

    /**
     * 工具栏模型
     *
     * @type {*}
     * @memberof BXDGridView
     */
    public toolBarModels: any = {
        tbitem3: { name: 'tbitem3', caption: '新建', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'New', target: '' } },

        tbitem4: { name: 'tbitem4', caption: '编辑', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Edit', target: 'SINGLEKEY' } },

        tbitem6: { name: 'tbitem6', caption: '拷贝', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Copy', target: 'SINGLEKEY' } },

        tbitem7: {  name: 'tbitem7', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem8: { name: 'tbitem8', caption: '删除', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Remove', target: 'MULTIKEY' } },

        tbitem9: {  name: 'tbitem9', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem13: { name: 'tbitem13', caption: '导出', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'ExportExcel', target: '' }, MaxRowCount: 1000  },

        tbitem10: {  name: 'tbitem10', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem16: { name: 'tbitem16', caption: '其它', disabled: false, type: 'ITEMS', visabled: true, dataaccaction: '', uiaction: { } }, 
 tbitem21: { name: 'tbitem21', caption: '导出数据模型', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'ExportModel', target: '' } },

 tbitem23: { name: 'tbitem23', caption: '数据导入', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Import', target: '' } },


        tbitem17: {  name: 'tbitem17', type: 'SEPERATOR', visabled: true, dataaccaction: '', uiaction: { } },
        tbitem19: { name: 'tbitem19', caption: '过滤', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'ToggleFilter', target: '' } },

        tbitem18: { name: 'tbitem18', caption: '帮助', disabled: false, type: 'DEUIACTION', visabled: true, dataaccaction: '', uiaction: { tag: 'Help', target: '' } },

    };


    /**
     * 视图加载完成事件
     *
     * @type {EventEmitter<any>}
     * @memberof BXDGridView
     */
    @Output() public viewloadEvent: EventEmitter<any> = new EventEmitter<any>();

    /**
     * 视图数据变化事件
     *
     * @type {EventEmitter<any>}
     * @memberof BXDGridView
     */
    @Output() public viewdataschangeEvent: EventEmitter<any> = new EventEmitter<any>();

    /**
     * 视图模型数据
     *
     * @type {*}
     * @memberof BXDGridView
     */
    public model: any = {
        srfTitle: '报销单表格视图',
        srfCaption: '报销单',
        srfSubCaption: '',
        dataInfo: ''
    };

    /**
     * 视图引擎
     *
     * @private
     * @type {Engine}
     * @memberof BXDGridView
     */
    private engine: GridViewEngine = new GridViewEngine();

    /**
     * 引擎初始化
     *
     * @private
     * @memberof BXDGridView
     */
    private engineInit(): void {
        this.engine.init({
            view: this,
            opendata: (args: any[], params?: any, $event?: any, xData?: any) => {
                this.opendata(args, params, $event, xData);
            },
            newdata: (args: any[], params?: any, $event?: any, xData?: any) => {
                this.newdata(args, params, $event, xData);
            },
            grid: this.grid,
            searchform: this.searchform,
            isLoadDefault: true,
        });
    }

    /**
     * angular生命周期
     *
     * @memberof BXDGridView
     */
    public ngOnInit() {

    }

     /**
     * angular生命周期(在ngOnInit之后)
     *
     * @memberof BXDGridView
     */
    public ngAfterViewInit() {
        this.engineInit();
        
    }


    /**
     * toolbar 部件 click 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDGridView
     */
    public toolbar_click($event: any, $event2?: any) {
        if (Object.is($event.tag, 'tbitem3')) {
            this.toolbar_tbitem3_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem4')) {
            this.toolbar_tbitem4_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem5')) {
            this.toolbar_tbitem5_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem6')) {
            this.toolbar_tbitem6_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem24')) {
            this.toolbar_tbitem24_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem25')) {
            this.toolbar_tbitem25_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem8')) {
            this.toolbar_tbitem8_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem13')) {
            this.toolbar_tbitem13_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem11')) {
            this.toolbar_tbitem11_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem21')) {
            this.toolbar_tbitem21_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem23')) {
            this.toolbar_tbitem23_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem19')) {
            this.toolbar_tbitem19_click($event, '', $event2);
        }
        if (Object.is($event.tag, 'tbitem18')) {
            this.toolbar_tbitem18_click($event, '', $event2);
        }
    }


    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDGridView
     */
    public grid_rowdblclick($event: any, $event2?: any) {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }


    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof BXDGridView
     */
    public searchform_search($event: any, $event2?: any) {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }



    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem3_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.New(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem4_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Edit(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem5_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.View(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem6_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Copy(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem24_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.ToggleRowEdit(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem25_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.NewRow(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem8_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Remove(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem13_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.ExportExcel(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem11_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Print(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem21_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.ExportModel(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem23_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Import(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem19_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.ToggleFilter(datas, paramJO,  $event, xData);
    }

    /**
     * 逻辑事件
     *
     * @param {*} [$event]
     * @param {*} [params={}]
     * @param {*} [tag]
     * @memberof 
     */
    public toolbar_tbitem18_click($event: any, params: any = {}, tag?: any) {
        // 参数

        // 取数
        let datas: any[] = [];
        let xData: any = null;
        // _this 指向容器对象
        const _this: any = this;
        const paramJO = {};
        xData = this.grid;
        if (xData.getDatas && xData.getDatas instanceof Function) {
            datas = [...xData.getDatas()];
        }

        // 界面行为
        this.Help(datas, paramJO,  $event, xData);
    }

    
    /**
     * 打开新建数据视图
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public newdata(args: any[], params?: any, $event?: any, xData?: any) {
        const data: any = {};
        if (args && args.length > 0 && args[0].srfsourcekey) {
            Object.assign(data, { srfsourcekey: args[0].srfsourcekey })
        }
        const _this: any = this;
        if (_this.srfparentdata) {
            Object.assign(data, _this.srfparentdata);
        }
        const openIndexViewTab = (viewpath: string, data: any) => {
            // const _params = this.$util.prepareRouteParmas({
            //     route: this.$route,
            //     sourceNode: this.$route.name,
            //     targetNode: viewpath,
            //     data: data,
            // });
            // this.$router.push({ name: viewpath, params: _params });
            this.$router.navigate([viewpath, data], {relativeTo: this.$route.parent.parent});
        }
        openIndexViewTab('test_bxdeditview', data);
    }


    /**
     * 打开编辑数据视图
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public opendata(args: any[], params?: any, $event?: any, xData?: any) {
        const data: any = { srfkey: args[0].srfkey, srfsourcekey: args[0].srfsourcekey };
        const _this: any = this;
        if (_this.srfparentdata) {
            Object.assign(data, _this.srfparentdata);
        }
        const openIndexViewTab = (viewpath: string, data: any) => {
            // const _params = this.$util.prepareRouteParmas({
            //     route: this.$route,
            //     sourceNode: this.$route.name,
            //     targetNode: viewpath,
            //     data: data,
            // });
            // this.$router.push({ name: viewpath, params: _params });
            this.$router.navigate([viewpath, data], {relativeTo: this.$route.parent.parent});
        }
        openIndexViewTab('test_bxdeditview', data);
    }



    /**
     * 新建
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public New(args: any[], params?: any, $event?: any, xData?: any) {
         const _this: any = this;
        if (_this.newdata && _this.newdata instanceof Function) {
            const data: any = {};
            if (_this.srfparentdata) {
                Object.assign(data, _this.srfparentdata);
            }
            _this.newdata([{ ...data }], params, $event, xData);
        } else {
            _this.$notice.error('错误', 'newdata 视图处理逻辑不存在，请添加!');
        }
    }

    /**
     * 编辑
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public Edit(args: any[], params?: any, $event?: any, xData?: any) {
        if (args.length === 0) {
            return;
        }
        const _this: any = this;
        if (_this.opendata && _this.opendata instanceof Function) {
            const data: any = { };
            if (args.length > 0) {
                Object.assign(data, { srfkey: args[0].srfkey })
            }
            if (_this.srfparentdata) {
                Object.assign(data, _this.srfparentdata);
            }
            _this.opendata([{ ...data }], params, $event, xData);
        } else {
            _this.$notice.error('错误', 'opendata 视图处理逻辑不存在，请添加!');
        }
    }

    /**
     * 查看
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public View(args: any[], params?: any, $event?: any, xData?: any) {
        if (args.length === 0) {
            return;
        }
        const _this: any = this;
        if (_this.opendata && _this.opendata instanceof Function) {
            const data: any = { };
            if (args.length > 0) {
                Object.assign(data, { srfkey: args[0].srfkey })
            }
            if (_this.srfparentdata) {
                Object.assign(data, _this.srfparentdata);
            }
            _this.opendata([{ ...data }], params, $event, xData);
        } else {
            _this.$Notice.error({ title: '错误', desc: 'opendata 视图处理逻辑不存在，请添加!' });
        }
    }

    /**
     * 拷贝
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public Copy(args: any[], params?: any, $event?: any, xData?: any) {
        if (args.length === 0) {
            return;
        }
        const _this: any = this;
        if (_this.newdata && _this.newdata instanceof Function) {
            const data: any = {};
            if (args.length > 0) {
                Object.assign(data, { srfsourcekey: args[0].srfkey })
            }
            if (_this.srfparentdata) {
                Object.assign(data, _this.srfparentdata);
            }
            _this.newdata([{ ...data }], params, $event, xData);
        } else if (xData && xData.copy instanceof Function) {
            const data2: any = {};
            if (args.length > 0) {
                Object.assign(data2, { srfsourcekey: args[0].srfkey })
            }
            if (_this.srfparentdata) {
                Object.assign(data2, _this.srfparentdata);
            }
            xData.copy(data2);
        } else {
            _this.$Notice.error({ title: '错误', desc: 'opendata 视图处理逻辑不存在，请添加!' });
        }
    }

    /**
     * 行编辑
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public ToggleRowEdit(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 新建行
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public NewRow(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 删除
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public Remove(args: any[], params?: any, $event?: any, xData?: any) {
        const _this: any = this;
        if (!xData || !(xData.remove instanceof Function)) {
            return ;
        }
        xData.remove(args);
    }


    /**
     * 导出
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public ExportExcel(args: any[], params?: any, $event?: any, xData?: any) {
        const _this: any = this;
        if (!xData || !(xData.exportExcel instanceof Function) || !$event) {
            return ;
        }
        xData.exportExcel($event.exportparms);
    }

    /**
     * 打印
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public Print(args: any[], params?: any, $event?: any, xData?: any) {

    }

    /**
     * 导出数据模型
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public ExportModel(args: any[], params?: any, $event?: any, xData?: any) {
        const _this: any = this;
        if (!xData || !(xData.exportModel instanceof Function)) {
            return ;
        }
        xData.exportModel(args);
    }

    /**
     * 数据导入
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public Import(args: any[], params?: any, $event?: any, xData?: any) {
        const _this: any = this;
        if (!xData || !(xData.import instanceof Function)) {
            return ;
        }
        xData.import(args);
    }

    /**
     * 过滤
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public ToggleFilter(args: any[], params?: any, $event?: any, xData?: any) {
        const _this: any = this;
        if (_this.hasOwnProperty('isExpandSearchForm')) {
            _this.isExpandSearchForm = !_this.isExpandSearchForm;
        }
    }

    /**
     * 帮助
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof BXDGridView
     */
    public Help(args: any[], params?: any, $event?: any, xData?: any) {

    }


    /**
     * 是否单选
     *
     * @type {boolean}
     * @memberof BXDGridView
     */
    public isSingleSelect: boolean = false;

    /**
     * 搜索值
     *
     * @type {string}
     * @memberof BXDGridView
     */
    public query: string = '';

    /**
     * 是否展开搜索表单
     *
     * @type {boolean}
     * @memberof BXDGridView
     */
    public isExpandSearchForm: boolean = false;

    /**
     * 表格行数据默认激活模式
     * 0 不激活
     * 1 单击激活
     * 2 双击激活
     *
     * @type {(number | 0 | 1 | 2)}
     * @memberof BXDGridView
     */
    public gridRowActiveMode: number | 0 | 1 | 2 = 2;

    /**
     * 快速搜索
     *
     * @param {*} $event
     * @memberof BXDGridView
     */
    public onSearch($event: any): void {
        const grid: any = this.grid;
        if (grid) {
            grid.load({});
        }
    }

    /**
     * 刷新数据
     *
     * @readonly
     * @type {(number | null)}
     * @memberof BXDGridView
     */
    get refreshdata(): number | null {
        return null;
    }


}
